# OpenFisca-US

This is a project in its early stages to explore a working prototype of the US tax and benefit system modeled with the OpenFisca simulation framework.
 
To install, run ```pip install git+https://github.com/policyengine/openfisca-us```.

To contribute, please see the [wiki](https://github.com/PolicyEngine/openfisca-us/wiki).
